package com.chuanglan.shanyan_sdk_test_demo.view;

import android.annotation.TargetApi;
import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;

import com.bumptech.glide.Glide;
import com.chuanglan.shanyan_sdk.OneKeyLoginManager;
import com.chuanglan.shanyan_sdk.listener.OneKeyLoginListener;
import com.chuanglan.shanyan_sdk.listener.OpenLoginAuthListener;
import com.chuanglan.shanyan_sdk_test_demo.R;
import com.chuanglan.shanyan_sdk_test_demo.utils.AbScreenUtils;
import com.chuanglan.shanyan_sdk_test_demo.utils.ConfigUtils;
import com.yanzhenjie.permission.Action;
import com.yanzhenjie.permission.AndPermission;
import com.yanzhenjie.permission.Permission;

import java.util.List;

public class StartActivity extends AppCompatActivity {
    private ImageView iv_flash;
    private CustomDialog dialog;
    private long startTime;
    private String type;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_start);
        initViews();
    }

    private void initViews() {
        Intent intent = getIntent();
        type = intent.getStringExtra("type");
        iv_flash = findViewById(R.id.iv_flash);
        int width = AbScreenUtils.getScreenWidth(getApplicationContext());
        int height = 1010 * width / 1242;
        AbScreenUtils.setViewWH(iv_flash, width, height);
        Glide.with(this).load(R.mipmap.gif).into(iv_flash);
    }

    public void doClick(View view) {
        if (dialog == null) {
            dialog = new CustomDialog(this);
        }
        dialog.show();
        //权限判断：调用拉起授权页前需要获取READ_PHONE_STATE权限，否则会返回失败状态码
        requestPermission(Permission.READ_PHONE_STATE);
    }


    private void requestPermission(String... permissions) {
        AndPermission.with(this)
                .permission(permissions)
                .onGranted(new Action() {
                    @TargetApi(Build.VERSION_CODES.M)
                    @Override
                    public void onAction(List<String> permissions) {
                        //自定义运营商授权页界面
                        if (type.equals("normal")) {
                            OneKeyLoginManager.getInstance().setAuthThemeConfig(ConfigUtils.getUiConfig(getApplicationContext()));
                        } else {
                            OneKeyLoginManager.getInstance().setAuthThemeConfig(ConfigUtils.getCJSConfig(getApplicationContext()));
                        }
                        //开始拉取授权页
                        OneKeyLoginManager.getInstance().openLoginAuth(false, 10, new OpenLoginAuthListener() {
                            @Override
                            public void getOpenLoginAuthStatus(int code, String result) {
                                if (code != 1000) {
                                    if (dialog != null) {
                                        dialog.cancel();
                                    }
                                    AbScreenUtils.showToast(getApplicationContext(), result);
                                }
                                Log.e("VVV", "getAuthCode=" + code + "result=" + result);
                            }
                        }, new OneKeyLoginListener() {
                            @Override
                            public void getOneKeyLoginStatus(int code, String result) {
                                if (dialog != null) {
                                    dialog.cancel();
                                }
                                dataProcessing(code, result);
                            }
                        });
                    }
                })
                .onDenied(new Action() {
                    @Override
                    public void onAction(@NonNull List<String> permissions) {
                        //自定义运营商授权页界面
                        if (type.equals("normal")) {
                            OneKeyLoginManager.getInstance().setAuthThemeConfig(ConfigUtils.getUiConfig(getApplicationContext()));
                        } else {
                            OneKeyLoginManager.getInstance().setAuthThemeConfig(ConfigUtils.getCJSConfig(getApplicationContext()));
                        }
                        //开始拉取授权页
                        OneKeyLoginManager.getInstance().openLoginAuth(false, 10, new OpenLoginAuthListener() {
                            @Override
                            public void getOpenLoginAuthStatus(int code, String result) {
                                if (code != 1000) {
                                    if (dialog != null) {
                                        dialog.cancel();
                                    }
                                    AbScreenUtils.showToast(getApplicationContext(), result);
                                }
                                Log.e("VVV", "getAuthCode=" + code + "result=" + result);
                            }
                        }, new OneKeyLoginListener() {
                            @Override
                            public void getOneKeyLoginStatus(int code, String result) {
                                if (dialog != null) {
                                    dialog.cancel();
                                }
                                dataProcessing(code, result);
                            }
                        });
                    }
                })
                .start();
    }

    private void dataProcessing(int code, String result) {
        Log.e("VVV", "拉起授权页code=" + code + "result==" + result);
        startTime = System.currentTimeMillis();
        startResultActivity(code, result);
    }

    private void startResultActivity(int code, String result) {
        Intent intent = new Intent(StartActivity.this, LoginResultActivity.class);
        intent.putExtra("startTime", startTime);
        intent.putExtra("loginResult", result);
        intent.putExtra("loginCode", code);
        startActivity(intent);
        //销毁授权页
        OneKeyLoginManager.getInstance().finishAuthActivity();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (dialog != null) {
            dialog.dismiss();
        }
        OneKeyLoginManager.getInstance().removeAllListener();
    }

    @Override
    protected void onStop() {
        super.onStop();
        if (dialog != null) {
            dialog.dismiss();
        }
    }
}
